cljs port of the original ring.core.protocols
Intended as a placeholder until the day Ring gets a platform-agnostic version.
cljs port of the original ring.core.protocols Intended as a placeholder until the day Ring gets a platform-agnostic version.
A protocol for writing data to the response body via a writable stream.
A protocol for writing data to the response body via a writable stream.
(write-body-to-stream body response output-stream)Write a value representing a response body to a writable stream. The stream will be ended after the value has been written.
Write a value representing a response body to a writable stream. The stream will be ended after the value has been written.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |